@@ -7,8 +7,9 @@ from streaming.base.dataloader import StreamingDataLoader
 from streaming.base.dataset import StreamingDataset
 from streaming.base.format import CSVWriter, JSONWriter, MDSWriter, TSVWriter, XSVWriter
 from streaming.base.local import LocalDataset
+from streaming.base.stream import Stream
 
 __all__ = [
-    'StreamingDataLoader', 'StreamingDataset', 'CSVWriter', 'JSONWriter', 'LocalDataset',
+    'StreamingDataLoader', 'Stream', 'StreamingDataset', 'CSVWriter', 'JSONWriter', 'LocalDataset',
     'MDSWriter', 'TSVWriter', 'XSVWriter'
 ]
