@@ -29,12 +29,13 @@ class Writer(ABC):
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in the
+               `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset directory
             or remove it after uploading. Defaults to ``False``.
         compression (str, optional): Optional compression or compression:level. Defaults to
@@ -48,6 +49,12 @@ class Writer(ABC):
         extra_bytes_per_sample (int): Extra bytes per serialized sample (for computing shard size
             while writing). Defaults to ``0``.
         **kwargs (Any): Additional settings for the Writer.
+
+            progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+                a remote location. Default to ``False``.
+            max_workers (int): Maximum number of threads used to upload output dataset files in
+                parallel to a remote location. One thread is responsible for uploading one shard
+                file to a remote location. Default to ``min(32, (os.cpu_count() or 1) + 4)``.
     """
 
     format: str = ''  # Name of the format (like "mds", "csv", "json", etc).
@@ -241,7 +248,7 @@ class Writer(ABC):
             self._reset_cache()
         self._write_index()
         logger.debug(f'Waiting for all shard files to get uploaded to {self.remote}')
-        self.executor.shutdown(wait=True, cancel_futures=False)
+        self.executor.shutdown(wait=True)
         if self.remote and not self.keep_local:
             shutil.rmtree(self.local)
 
@@ -270,12 +277,13 @@ class JointWriter(Writer):
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in the
+               `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset directory
             or remove it after uploading. Defaults to ``False``.
         compression (str, optional): Optional compression or compression:level. Defaults to
@@ -289,6 +297,12 @@ class JointWriter(Writer):
         extra_bytes_per_sample (int): Extra bytes per serialized sample (for computing shard size
             while writing). Defaults to ``0``.
         **kwargs (Any): Additional settings for the Writer.
+
+            progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+                a remote location. Default to ``False``.
+            max_workers (int): Maximum number of threads used to upload output dataset files in
+                parallel to a remote location. One thread is responsible for uploading one shard
+                file to a remote location. Default to ``min(32, (os.cpu_count() or 1) + 4)``.
     """
 
     def __init__(self,
@@ -342,12 +356,13 @@ class SplitWriter(Writer):
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in the
+               `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset directory
             or remove it after uploading. Defaults to ``False``.
         compression (str, optional): Optional compression or compression:level. Defaults to
@@ -357,6 +372,12 @@ class SplitWriter(Writer):
         size_limit (int, optional): Optional shard size limit, after which point to start a new
             shard. If None, puts everything in one shard. Defaults to ``1 << 26``.
         **kwargs (Any): Additional settings for the Writer.
+
+            progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+                a remote location. Default to ``False``.
+            max_workers (int): Maximum number of threads used to upload output dataset files in
+                parallel to a remote location. One thread is responsible for uploading one shard
+                file to a remote location. Default to ``min(32, (os.cpu_count() or 1) + 4)``.
     """
 
     extra_bytes_per_shard = 0
