@@ -37,16 +37,17 @@ class CloudUploader:
 
         Args:
             out (str | Tuple[str, str]): Output dataset directory to save shard files.
-                1. If `out` is a local directory, shard files are saved locally.
-                2. If `out` is a remote directory, a local temporary directory is created to
+
+                1. If ``out`` is a local directory, shard files are saved locally.
+                2. If ``out`` is a remote directory, a local temporary directory is created to
                    cache the shard files and then the shard files are uploaded to a remote
                    location. At the end, the temp directory is deleted once shards are uploaded.
-                3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                   `local_dir` and also uploaded to a remote location.
+                3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+                   the `local_dir` and also uploaded to a remote location.
             keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
                 shard file or remove it after uploading. Defaults to ``False``.
-            progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-                provider. Defaults to ``False``.
+            progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+                a remote location. Default to ``False``.
 
         Returns:
             CloudUploader: An instance of sub-class.
@@ -60,12 +61,13 @@ class CloudUploader:
 
         Args:
             out (str | Tuple[str, str]): Output dataset directory to save shard files.
-                1. If `out` is a local directory, shard files are saved locally.
-                2. If `out` is a remote directory, a local temporary directory is created to
+
+                1. If ``out`` is a local directory, shard files are saved locally.
+                2. If ``out`` is a remote directory, a local temporary directory is created to
                    cache the shard files and then the shard files are uploaded to a remote
                    location. At the end, the temp directory is deleted once shards are uploaded.
-                3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                   `local_dir` and also uploaded to a remote location.
+                3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+                   the `local_dir` and also uploaded to a remote location.
 
         Raises:
             ValueError: Invalid number of `out` argument.
@@ -91,16 +93,17 @@ class CloudUploader:
 
         Args:
             out (str | Tuple[str, str]): Output dataset directory to save shard files.
-                1. If `out` is a local directory, shard files are saved locally.
-                2. If `out` is a remote directory, a local temporary directory is created to
+
+                1. If ``out`` is a local directory, shard files are saved locally.
+                2. If ``out`` is a remote directory, a local temporary directory is created to
                    cache the shard files and then the shard files are uploaded to a remote
                    location. At the end, the temp directory is deleted once shards are uploaded.
-                3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                   `local_dir` and also uploaded to a remote location.
+                3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+                   the `local_dir` and also uploaded to a remote location.
             keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
                 shard file or remove it after uploading. Defaults to ``False``.
-            progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-                provider. Defaults to ``False``.
+            progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+                a remote location. Default to ``False``.
 
         Raises:
             FileExistsError: Local directory must be empty.
@@ -152,16 +155,17 @@ class S3Uploader(CloudUploader):
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+               the `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
             shard file or remove it after uploading. Defaults to ``False``.
-        progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-            provider. Defaults to ``False``.
+        progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+            a remote location. Default to ``False``.
     """
 
     def __init__(self,
@@ -174,6 +178,7 @@ class S3Uploader(CloudUploader):
         from botocore.config import Config
         config = Config()
         self.s3 = boto3.client('s3', config=config)
+        self.check_bucket_exists(self.remote)  # pyright: ignore
 
     def upload_file(self, filename: str):
         """Upload file from local instance to AWS S3 bucket.
@@ -199,22 +204,43 @@ class S3Uploader(CloudUploader):
             )
         self.clear_local(local=local_filename)
 
+    def check_bucket_exists(self, remote: str):
+        """Raise an exception if the bucket does not exist.
+
+        Args:
+            remote (str): S3 bucket path.
+
+        Raises:
+            error: Bucket does not exist.
+        """
+        from botocore.exceptions import ClientError
+
+        bucket_name = urllib.parse.urlparse(remote).netloc
+        try:
+            self.s3.head_bucket(Bucket=bucket_name)
+        except ClientError as error:
+            if error.response['Error']['Code'] == '404':
+                error.args = (f'Bucket `{bucket_name}` does not exist! ' +
+                              f'Check the bucket permission or create the bucket.',)
+            raise error
+
 
 class GCSUploader(CloudUploader):
     """Upload file from local machine to Google Cloud Storage bucket.
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+               the `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
             shard file or remove it after uploading. Defaults to ``False``.
-        progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-            provider. Defaults to ``False``.
+        progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+            a remote location. Default to ``False``.
     """
 
     def __init__(self,
@@ -230,6 +256,7 @@ class GCSUploader(CloudUploader):
                                        endpoint_url='https://storage.googleapis.com',
                                        aws_access_key_id=os.environ['GCS_KEY'],
                                        aws_secret_access_key=os.environ['GCS_SECRET'])
+        self.check_bucket_exists(self.remote)  # pyright: ignore
 
     def upload_file(self, filename: str):
         """Upload file from local instance to Google Cloud Storage bucket.
@@ -255,22 +282,43 @@ class GCSUploader(CloudUploader):
             )
         self.clear_local(local=local_filename)
 
+    def check_bucket_exists(self, remote: str):
+        """Raise an exception if the bucket does not exist.
+
+        Args:
+            remote (str): S3 bucket path.
+
+        Raises:
+            error: Bucket does not exist.
+        """
+        from botocore.exceptions import ClientError
+
+        bucket_name = urllib.parse.urlparse(remote).netloc
+        try:
+            self.gcs_client.head_bucket(Bucket=bucket_name)
+        except ClientError as error:
+            if error.response['Error']['Code'] == '404':
+                error.args = (f'Bucket `{bucket_name}` does not exist! ' +
+                              f'Check the bucket permission or create the bucket.',)
+            raise error
+
 
 class OCIUploader(CloudUploader):
     """Upload file from local machine to Oracle Cloud Infrastructure (OCI) Cloud Storage.
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+               the `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
             shard file or remove it after uploading. Defaults to ``False``.
-        progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-            provider. Defaults to ``False``.
+        progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+            a remote location. Default to ``False``.
     """
 
     def __init__(self,
@@ -281,10 +329,11 @@ class OCIUploader(CloudUploader):
 
         import oci
         config = oci.config.from_file()
-        client = oci.object_storage.ObjectStorageClient(
+        self.client = oci.object_storage.ObjectStorageClient(
             config=config, retry_strategy=oci.retry.DEFAULT_RETRY_STRATEGY)
-        self.namespace = client.get_namespace().data
-        self.upload_manager = oci.object_storage.UploadManager(client)
+        self.namespace = self.client.get_namespace().data
+        self.upload_manager = oci.object_storage.UploadManager(self.client)
+        self.check_bucket_exists(self.remote)  # pyright: ignore
 
     def upload_file(self, filename: str):
         """Upload file from local instance to OCI Cloud Storage bucket.
@@ -314,22 +363,44 @@ class OCIUploader(CloudUploader):
             )
         self.clear_local(local=local_filename)
 
+    def check_bucket_exists(self, remote: str):
+        """Raise an exception if the bucket does not exist.
+
+        Args:
+            remote (str): S3 bucket path.
+
+        Raises:
+            error: Bucket does not exist.
+        """
+        from oci.exceptions import ServiceError
+
+        obj = urllib.parse.urlparse(remote)
+        bucket_name = obj.netloc.split('@' + self.namespace)[0]
+        try:
+            self.client.head_bucket(bucket_name=bucket_name, namespace_name=self.namespace)
+        except ServiceError as error:
+            if error.status == 404:
+                error.args = (f'Bucket `{bucket_name}` does not exist! ' +
+                              f'Check the bucket permission or create the bucket.',)
+            raise error
+
 
 class LocalUploader(CloudUploader):
     """Copy file from one local directory to another local directory.
 
     Args:
         out (str | Tuple[str, str]): Output dataset directory to save shard files.
-            1. If `out` is a local directory, shard files are saved locally.
-            2. If `out` is a remote directory, a local temporary directory is created to
-                cache the shard files and then the shard files are uploaded to a remote
-                location. At the end, the temp directory is deleted once shards are uploaded.
-            3. If `out` is a tuple of `(local_dir, remote_dir)`, shard files are saved in the
-                `local_dir` and also uploaded to a remote location.
+
+            1. If ``out`` is a local directory, shard files are saved locally.
+            2. If ``out`` is a remote directory, a local temporary directory is created to
+               cache the shard files and then the shard files are uploaded to a remote
+               location. At the end, the temp directory is deleted once shards are uploaded.
+            3. If ``out`` is a tuple of ``(local_dir, remote_dir)``, shard files are saved in
+               the `local_dir` and also uploaded to a remote location.
         keep_local (bool): If the dataset is uploaded, whether to keep the local dataset
             shard file or remove it after uploading. Defaults to ``False``.
-        progress_bar (bool): Whether to display a progress bar while uploading to a cloud
-            provider. Defaults to ``False``.
+        progress_bar (bool): Display TQDM progress bars for uploading output dataset files to
+            a remote location. Default to ``False``.
     """
 
     def __init__(self,
