@@ -39,9 +39,10 @@ def mds_dataset_dir():
 @pytest.mark.parametrize('batch_size', [None, 1, 2])
 @pytest.mark.parametrize('remote_arg', ['none', 'same', 'different'])
 @pytest.mark.parametrize('shuffle', [False, True])
+@pytest.mark.parametrize('seed', [5151])
 @pytest.mark.usefixtures('mds_dataset_dir')
 def test_dataset_sample_order(mds_dataset_dir: Any, batch_size: int, remote_arg: str,
-                              shuffle: bool):
+                              shuffle: bool, seed: int):
     num_samples = 117
     remote_dir, local_dir = mds_dataset_dir
     if remote_arg == 'none':
@@ -58,7 +59,8 @@ def test_dataset_sample_order(mds_dataset_dir: Any, batch_size: int, remote_arg:
     dataset = StreamingDataset(local=local_dir,
                                remote=remote_dir,
                                shuffle=shuffle,
-                               batch_size=batch_size)
+                               batch_size=batch_size,
+                               shuffle_seed=seed)
 
     # Test basic sample order
     rcvd_samples = 0
@@ -89,7 +91,7 @@ def test_dataset_sample_order(mds_dataset_dir: Any, batch_size: int, remote_arg:
 
 
 @pytest.mark.parametrize('batch_size', [None, 1, 2])
-@pytest.mark.parametrize('seed', [987])
+@pytest.mark.parametrize('seed', [8988])
 @pytest.mark.parametrize('shuffle', [False, True])
 @pytest.mark.usefixtures('mds_dataset_dir')
 def test_dataset_determinism(mds_dataset_dir: Any, batch_size: int, seed: int, shuffle: bool):
@@ -129,8 +131,9 @@ def test_dataset_determinism(mds_dataset_dir: Any, batch_size: int, seed: int, s
     'missing_file',
     ['index'],
 )
+@pytest.mark.parametrize('seed', [7777])
 @pytest.mark.usefixtures('mds_dataset_dir')
-def test_reader_download_fail(mds_dataset_dir: Any, missing_file: str):
+def test_reader_download_fail(mds_dataset_dir: Any, missing_file: str, seed: int):
     remote_dir, local_dir = mds_dataset_dir
 
     if missing_file == 'index':
@@ -141,7 +144,8 @@ def test_reader_download_fail(mds_dataset_dir: Any, missing_file: str):
         dataset = StreamingDataset(local=local_dir,
                                    remote=remote_dir,
                                    shuffle=False,
-                                   download_timeout=1)
+                                   download_timeout=1,
+                                   shuffle_seed=seed)
         for _ in dataset:
             pass
     assert exc_info.match(r'.*No such file or directory*')
@@ -149,8 +153,10 @@ def test_reader_download_fail(mds_dataset_dir: Any, missing_file: str):
 
 @pytest.mark.parametrize('created_ago', [0.5, 1.0])
 @pytest.mark.parametrize('download_timeout', [1])
+@pytest.mark.parametrize('seed', [2569])
 @pytest.mark.usefixtures('mds_dataset_dir')
-def test_reader_after_crash(mds_dataset_dir: Any, created_ago: float, download_timeout: float):
+def test_reader_after_crash(mds_dataset_dir: Any, created_ago: float, download_timeout: float,
+                            seed: int):
     remote_dir, local_dir = mds_dataset_dir
 
     if not os.path.exists(local_dir):
@@ -165,7 +171,8 @@ def test_reader_after_crash(mds_dataset_dir: Any, created_ago: float, download_t
     dataset = StreamingDataset(local=local_dir,
                                remote=remote_dir,
                                shuffle=False,
-                               download_timeout=download_timeout)
+                               download_timeout=download_timeout,
+                               shuffle_seed=seed)
 
     # Iterate over dataset and make sure there are no TimeoutErrors
     for _ in dataset:
@@ -181,13 +188,17 @@ def test_reader_after_crash(mds_dataset_dir: Any, created_ago: float, download_t
 )
 @pytest.mark.usefixtures('mds_dataset_dir')
 @pytest.mark.parametrize('index', [17])
-def test_reader_getitem(mds_dataset_dir: Any, share_remote_local: bool, index: int):
+@pytest.mark.parametrize('seed', [5566])
+def test_reader_getitem(mds_dataset_dir: Any, share_remote_local: bool, index: int, seed: int):
     remote_dir, local_dir = mds_dataset_dir
     if share_remote_local:
         local_dir = remote_dir
 
     # Build a StreamingDataset
-    dataset = StreamingDataset(local=local_dir, remote=remote_dir, shuffle=False)
+    dataset = StreamingDataset(local=local_dir,
+                               remote=remote_dir,
+                               shuffle=False,
+                               shuffle_seed=seed)
 
     # Test retrieving random sample
     sample = dataset[index]
