@@ -15,13 +15,14 @@ from tests.common.datasets import SequenceDataset, write_mds_dataset
 @pytest.mark.parametrize('batch_size', [128])
 @pytest.mark.parametrize('drop_last', [False, True])
 @pytest.mark.parametrize('shuffle', [False, True])
-@pytest.mark.parametrize('num_workers', [0, 1, 8])
+@pytest.mark.parametrize('num_workers', [0, 4])
 @pytest.mark.parametrize('num_samples', [9867, 30_000])
 @pytest.mark.parametrize('size_limit', [8_192])
+@pytest.mark.parametrize('seed', [1234])
 @pytest.mark.usefixtures('local_remote_dir')
 def test_dataloader_single_device(local_remote_dir: Tuple[str, str], batch_size: int,
                                   drop_last: bool, shuffle: bool, num_workers: int,
-                                  num_samples: int, size_limit: int):
+                                  num_samples: int, size_limit: int, seed: int):
     dataset = SequenceDataset(num_samples)
     columns = dict(zip(dataset.column_names, dataset.column_encodings))
     local, remote = local_remote_dir
@@ -32,7 +33,7 @@ def test_dataloader_single_device(local_remote_dir: Tuple[str, str], batch_size:
                                remote=remote,
                                shuffle=shuffle,
                                batch_size=batch_size,
-                               shuffle_seed=123)
+                               shuffle_seed=seed)
 
     # Build DataLoader
     dataloader = DataLoader(dataset=dataset,
@@ -73,10 +74,10 @@ def test_dataloader_single_device(local_remote_dir: Tuple[str, str], batch_size:
         assert len(set(sample_order)) == num_samples
 
 
-@pytest.mark.parametrize('batch_size', [None, 1, 2, 4])
-@pytest.mark.parametrize('seed', [987])
+@pytest.mark.parametrize('batch_size', [1, 4])
+@pytest.mark.parametrize('seed', [1111])
 @pytest.mark.parametrize('shuffle', [False, True])
-@pytest.mark.parametrize('num_workers', [0, 1, 8])
+@pytest.mark.parametrize('num_workers', [0, 8])
 @pytest.mark.usefixtures('mds_dataset_dir')
 def test_dataloader_determinism(mds_dataset_dir: Any, batch_size: int, seed: int, shuffle: bool,
                                 num_workers: int):
@@ -96,8 +97,6 @@ def test_dataloader_determinism(mds_dataset_dir: Any, batch_size: int, seed: int
     sample_order = []
     for batch in dataloader:
         sample_order.extend(batch['id'][:])
-    del dataloader
-    del dataset
 
     # Build StreamingDataset again to test deterministic sample ID
     dataset = StreamingDataset(local=local_dir,
@@ -118,11 +117,11 @@ def test_dataloader_determinism(mds_dataset_dir: Any, batch_size: int, seed: int
     assert sample_order == second_sample_order
 
 
-@pytest.mark.parametrize('batch_size', [1, 2, 4])
-@pytest.mark.parametrize('seed', [987])
+@pytest.mark.parametrize('batch_size', [1, 4])
+@pytest.mark.parametrize('seed', [2222])
 @pytest.mark.parametrize('shuffle', [False])
 @pytest.mark.parametrize('drop_last', [False, True])
-@pytest.mark.parametrize('num_workers', [0, 1, 8])
+@pytest.mark.parametrize('num_workers', [0, 8])
 @pytest.mark.usefixtures('mds_dataset_dir')
 def test_dataloader_sample_order(mds_dataset_dir: Any, batch_size: int, seed: int, shuffle: bool,
                                  drop_last: bool, num_workers: int):
@@ -155,10 +154,10 @@ def test_dataloader_sample_order(mds_dataset_dir: Any, batch_size: int, seed: in
     assert expected_sample_order == sample_order
 
 
-@pytest.mark.parametrize('batch_size', [1, 2, 4])
-@pytest.mark.parametrize('seed', [987])
+@pytest.mark.parametrize('batch_size', [1, 4])
+@pytest.mark.parametrize('seed', [3456])
 @pytest.mark.parametrize('shuffle', [False, True])
-@pytest.mark.parametrize('num_workers', [0, 1, 4, 8])
+@pytest.mark.parametrize('num_workers', [0, 4])
 @pytest.mark.usefixtures('mds_dataset_dir')
 def test_streamingdataloader_mid_epoch_resumption(mds_dataset_dir: Any, batch_size: int, seed: int,
                                                   shuffle: bool, num_workers: int):
@@ -188,9 +187,6 @@ def test_streamingdataloader_mid_epoch_resumption(mds_dataset_dir: Any, batch_si
             break
         sample_order.extend(batch['id'][:])
 
-    del dataloader
-    del dataset
-
     dataset = StreamingDataset(local=local_dir,
                                remote=remote_dir,
                                shuffle=shuffle,
